@@ -4,13 +4,16 @@ use crate::diagnostic::{LintDiagnostic, Position, Range};
 use crate::ignore_directives::{
   CodeStatus, FileIgnoreDirective, LineIgnoreDirective,
 };
-use crate::rules::{get_all_rules, LintRule};
+use crate::rules::{self, get_all_rules, LintRule};
 use crate::scopes::Scope;
 use deno_ast::swc::common::comments::Comment;
+use deno_ast::swc::common::BytePos;
 use deno_ast::swc::common::{Span, SyntaxContext};
 use deno_ast::view as ast_view;
-use deno_ast::view::{BytePos, RootNode, SourceFile};
+use deno_ast::view::{RootNode, SourceFile};
+use deno_ast::MediaType;
 use std::collections::{HashMap, HashSet};
+use std::sync::Arc;
 use std::time::Instant;
 
 /// `Context` stores data needed while performing all lint rules to a file.
@@ -18,6 +21,10 @@ pub struct Context<'view> {
   /// File name on which the lint rule is run
   file_name: String,
 
+  /// The media type which linter was configured with. Can be used
+  /// to skip checking some rules.
+  media_type: MediaType,
+
   /// Stores diagnostics that are generated while linting
   diagnostics: Vec<LintDiagnostic>,
 
@@ -49,12 +56,16 @@ pub struct Context<'view> {
 
   /// A value to control whether the node's children will be traversed or not.
   traverse_flow: TraverseFlow,
+
+  /// Whether to check unknown rules
+  check_unknown_rules: bool,
 }
 
 impl<'view> Context<'view> {
   #[allow(clippy::too_many_arguments)]
   pub(crate) fn new(
     file_name: String,
+    media_type: MediaType,
     source_file: &'view impl SourceFile,
     program: ast_view::Program<'view>,
     file_ignore_directive: Option<FileIgnoreDirective>,
@@ -62,9 +73,11 @@ impl<'view> Context<'view> {
     scope: Scope,
     control_flow: ControlFlow,
     top_level_ctxt: SyntaxContext,
+    check_unknown_rules: bool,
   ) -> Self {
     Self {
       file_name,
+      media_type,
       source_file,
       program,
       file_ignore_directive,
@@ -75,12 +88,17 @@ impl<'view> Context<'view> {
       diagnostics: Vec::new(),
       plugin_codes: HashSet::new(),
       traverse_flow: TraverseFlow::default(),
+      check_unknown_rules,
     }
   }
   pub fn file_name(&self) -> &str {
     &self.file_name
   }
 
+  pub fn media_type(&self) -> MediaType {
+    self.media_type
+  }
+
   pub fn diagnostics(&self) -> &[LintDiagnostic] {
     &self.diagnostics
   }
@@ -134,11 +152,7 @@ impl<'view> Context<'view> {
   }
 
   pub fn all_comments(&self) -> impl Iterator<Item = &'view Comment> {
-    self
-      .program
-      .comments()
-      .expect("Program should have information about comments, but doesn't")
-      .all_comments()
+    self.program.comment_container().unwrap().all_comments()
   }
 
   pub fn leading_comments_at(
@@ -147,8 +161,8 @@ impl<'view> Context<'view> {
   ) -> impl Iterator<Item = &'view Comment> {
     self
       .program
-      .comments()
-      .expect("Program should have information about comments, but doesn't")
+      .comment_container()
+      .unwrap()
       .leading_comments(lo)
   }
 
@@ -158,8 +172,8 @@ impl<'view> Context<'view> {
   ) -> impl Iterator<Item = &'view Comment> {
     self
       .program
-      .comments()
-      .expect("Program should have information about comments, but doesn't")
+      .comment_container()
+      .unwrap()
       .trailing_comments(hi)
   }
 
@@ -199,7 +213,7 @@ impl<'view> Context<'view> {
   /// works for diagnostics reported by other rules.
   pub(crate) fn ban_unused_ignore(
     &self,
-    specified_rules: &[Box<dyn LintRule>],
+    specified_rules: &[Arc<dyn LintRule>],
   ) -> Vec<LintDiagnostic> {
     const CODE: &str = "ban-unused-ignore";
 
@@ -262,7 +276,7 @@ impl<'view> Context<'view> {
   /// This should be run after all normal rules have been finished because
   /// currently we collect the rule codes of plugins as they are run and thus
   /// there's no way of knowing what are the "known" rule codes beforehand.
-  pub(crate) fn ban_unknown_rule_code(&self) -> Vec<LintDiagnostic> {
+  pub(crate) fn ban_unknown_rule_code(&mut self) -> Vec<LintDiagnostic> {
     let builtin_all_rule_codes: HashSet<&'static str> =
       get_all_rules().iter().map(|r| r.code()).collect();
     let is_unknown_rule = |code: &&String| {
@@ -278,7 +292,7 @@ impl<'view> Context<'view> {
       {
         let d = self.create_diagnostic(
           file_ignore.span(),
-          "ban-unknown-rule-code",
+          rules::ban_unknown_rule_code::CODE,
           format!("Unknown rule for code \"{}\"", unknown_rule_code),
           None,
         );
@@ -292,7 +306,7 @@ impl<'view> Context<'view> {
       {
         let d = self.create_diagnostic(
           line_ignore.span(),
-          "ban-unknown-rule-code",
+          rules::ban_unknown_rule_code::CODE,
           format!("Unknown rule for code \"{}\"", unknown_rule_code),
           None,
         );
@@ -300,7 +314,22 @@ impl<'view> Context<'view> {
       }
     }
 
-    diagnostics
+    if !diagnostics.is_empty() {
+      if let Some(f) = self.file_ignore_directive.as_mut() {
+        f.check_used(rules::ban_unknown_rule_code::CODE);
+      }
+    }
+
+    if self.check_unknown_rules
+      && !self
+        .file_ignore_directive()
+        .map(|f| f.has_code(rules::ban_unknown_rule_code::CODE))
+        .unwrap_or(false)
+    {
+      diagnostics
+    } else {
+      vec![]
+    }
   }
 
   pub fn add_diagnostic(
