@@ -3,10 +3,11 @@ use super::{Context, LintRule};
 use crate::handler::{Handler, Traverse};
 use crate::swc_util::StringRepr;
 use crate::{Program, ProgramRef};
+use deno_ast::swc::common::Spanned;
 use deno_ast::view as ast_view;
-use deno_ast::view::Spanned;
 use derive_more::Display;
 use std::collections::HashSet;
+use std::sync::Arc;
 
 #[derive(Debug)]
 pub struct AdjacentOverloadSignatures;
@@ -26,8 +27,8 @@ enum AdjacentOverloadSignaturesHint {
 }
 
 impl LintRule for AdjacentOverloadSignatures {
-  fn new() -> Box<Self> {
-    Box::new(AdjacentOverloadSignatures)
+  fn new() -> Arc<Self> {
+    Arc::new(AdjacentOverloadSignatures)
   }
 
   fn tags(&self) -> &'static [&'static str] {
