@@ -6,6 +6,7 @@ use deno_ast::swc::common::comments::CommentKind;
 use deno_ast::swc::common::Span;
 use once_cell::sync::Lazy;
 use regex::Regex;
+use std::sync::Arc;
 
 /// This rule differs from typescript-eslint. In typescript-eslint the following
 /// defaults apply:
@@ -61,8 +62,8 @@ impl BanTsComment {
 }
 
 impl LintRule for BanTsComment {
-  fn new() -> Box<Self> {
-    Box::new(BanTsComment)
+  fn new() -> Arc<Self> {
+    Arc::new(BanTsComment)
   }
 
   fn tags(&self) -> &'static [&'static str] {
