@@ -22,7 +22,7 @@ impl LintRule for Camelcase {
   }
 
   fn tags(&self) -> &'static [&'static str] {
-    &["recommended"]
+    &[]
   }
 
   fn code(&self) -> &'static str {
