@@ -1,11 +1,11 @@
 // Copyright 2020-2021 the Deno authors. All rights reserved. MIT license.
-use super::{Context, LintRule, DUMMY_NODE};
+use super::{Context, LintRule};
 use crate::ProgramRef;
 use deno_ast::swc::ast::{
   DoWhileStmt, EmptyStmt, ForInStmt, ForOfStmt, ForStmt, IfStmt, LabeledStmt,
   Stmt, WhileStmt, WithStmt,
 };
-use deno_ast::swc::visit::{noop_visit_type, Node, Visit, VisitWith};
+use deno_ast::swc::visit::{noop_visit_type, Visit, VisitWith};
 use derive_more::Display;
 use std::sync::Arc;
 
@@ -46,8 +46,8 @@ impl LintRule for NoExtraSemi {
   ) {
     let mut visitor = NoExtraSemiVisitor::new(context);
     match program {
-      ProgramRef::Module(m) => m.visit_with(&DUMMY_NODE, &mut visitor),
-      ProgramRef::Script(s) => s.visit_with(&DUMMY_NODE, &mut visitor),
+      ProgramRef::Module(m) => m.visit_with(&mut visitor),
+      ProgramRef::Script(s) => s.visit_with(&mut visitor),
     }
   }
 
@@ -70,7 +70,7 @@ impl<'c, 'view> NoExtraSemiVisitor<'c, 'view> {
 impl<'c, 'view> Visit for NoExtraSemiVisitor<'c, 'view> {
   noop_visit_type!();
 
-  fn visit_empty_stmt(&mut self, empty_stmt: &EmptyStmt, _parent: &dyn Node) {
+  fn visit_empty_stmt(&mut self, empty_stmt: &EmptyStmt) {
     self.context.add_diagnostic_with_hint(
       empty_stmt.span,
       CODE,
@@ -79,86 +79,86 @@ impl<'c, 'view> Visit for NoExtraSemiVisitor<'c, 'view> {
     );
   }
 
-  fn visit_for_stmt(&mut self, for_stmt: &ForStmt, _: &dyn Node) {
+  fn visit_for_stmt(&mut self, for_stmt: &ForStmt) {
     if matches!(&*for_stmt.body, Stmt::Empty(_)) {
       if let Some(ref init) = for_stmt.init {
-        init.visit_with(for_stmt, self);
+        init.visit_with(self);
       }
       if let Some(ref test) = for_stmt.test {
-        test.visit_with(for_stmt, self);
+        test.visit_with(self);
       }
       if let Some(ref update) = for_stmt.update {
-        update.visit_with(for_stmt, self);
+        update.visit_with(self);
       }
     } else {
       for_stmt.visit_children_with(self);
     }
   }
 
-  fn visit_while_stmt(&mut self, while_stmt: &WhileStmt, _: &dyn Node) {
+  fn visit_while_stmt(&mut self, while_stmt: &WhileStmt) {
     if matches!(&*while_stmt.body, Stmt::Empty(_)) {
-      while_stmt.test.visit_with(while_stmt, self);
+      while_stmt.test.visit_with(self);
     } else {
       while_stmt.visit_children_with(self);
     }
   }
 
-  fn visit_do_while_stmt(&mut self, do_while_stmt: &DoWhileStmt, _: &dyn Node) {
+  fn visit_do_while_stmt(&mut self, do_while_stmt: &DoWhileStmt) {
     if matches!(&*do_while_stmt.body, Stmt::Empty(_)) {
-      do_while_stmt.test.visit_with(do_while_stmt, self);
+      do_while_stmt.test.visit_with(self);
     } else {
       do_while_stmt.visit_children_with(self);
     }
   }
 
-  fn visit_with_stmt(&mut self, with_stmt: &WithStmt, _: &dyn Node) {
+  fn visit_with_stmt(&mut self, with_stmt: &WithStmt) {
     if matches!(&*with_stmt.body, Stmt::Empty(_)) {
-      with_stmt.obj.visit_with(with_stmt, self);
+      with_stmt.obj.visit_with(self);
     } else {
       with_stmt.visit_children_with(self);
     }
   }
 
-  fn visit_for_of_stmt(&mut self, for_of_stmt: &ForOfStmt, _: &dyn Node) {
+  fn visit_for_of_stmt(&mut self, for_of_stmt: &ForOfStmt) {
     if matches!(&*for_of_stmt.body, Stmt::Empty(_)) {
-      for_of_stmt.left.visit_with(for_of_stmt, self);
-      for_of_stmt.right.visit_with(for_of_stmt, self);
+      for_of_stmt.left.visit_with(self);
+      for_of_stmt.right.visit_with(self);
     } else {
       for_of_stmt.visit_children_with(self);
     }
   }
 
-  fn visit_for_in_stmt(&mut self, for_in_stmt: &ForInStmt, _: &dyn Node) {
+  fn visit_for_in_stmt(&mut self, for_in_stmt: &ForInStmt) {
     if matches!(&*for_in_stmt.body, Stmt::Empty(_)) {
-      for_in_stmt.left.visit_with(for_in_stmt, self);
-      for_in_stmt.right.visit_with(for_in_stmt, self);
+      for_in_stmt.left.visit_with(self);
+      for_in_stmt.right.visit_with(self);
     } else {
       for_in_stmt.visit_children_with(self);
     }
   }
 
-  fn visit_if_stmt(&mut self, if_stmt: &IfStmt, _: &dyn Node) {
-    if_stmt.test.visit_with(if_stmt, self);
+  fn visit_if_stmt(&mut self, if_stmt: &IfStmt) {
+    if_stmt.test.visit_with(self);
     match &*if_stmt.cons {
       Stmt::Empty(_) => {}
       cons => {
-        cons.visit_with(if_stmt, self);
+        cons.visit_with(self);
       }
     }
     match if_stmt.alt.as_deref() {
       None | Some(Stmt::Empty(_)) => {}
       Some(alt) => {
-        alt.visit_with(if_stmt, self);
+        alt.visit_with(self);
       }
     }
   }
 
-  fn visit_labeled_stmt(&mut self, labeled_stmt: &LabeledStmt, _: &dyn Node) {
-    labeled_stmt.label.visit_with(labeled_stmt, self);
+  fn visit_labeled_stmt(&mut self, labeled_stmt: &LabeledStmt) {
+    labeled_stmt.label.visit_with(self);
     match &*labeled_stmt.body {
       Stmt::Empty(_) => {}
       body => {
-        body.visit_with(labeled_stmt, self);
+        body.visit_with(self);
       }
     }
   }
