@@ -2,8 +2,11 @@
 use super::{Context, LintRule};
 use crate::handler::{Handler, Traverse};
 use crate::{Program, ProgramRef};
+use deno_ast::swc::common::Span;
+use deno_ast::swc::common::Spanned;
 use deno_ast::view as ast_view;
-use deno_ast::view::{NodeTrait, Span, Spanned};
+use deno_ast::view::NodeTrait;
+use std::sync::Arc;
 
 #[derive(Debug)]
 pub struct NoThisBeforeSuper;
@@ -13,8 +16,8 @@ const MESSAGE: &str = "In the constructor of derived classes, `this` / `super` a
 const HINT: &str = "Call `super()` before using `this` or `super` keyword.";
 
 impl LintRule for NoThisBeforeSuper {
-  fn new() -> Box<Self> {
-    Box::new(NoThisBeforeSuper)
+  fn new() -> Arc<Self> {
+    Arc::new(NoThisBeforeSuper)
   }
 
   fn tags(&self) -> &'static [&'static str] {
