@@ -4,6 +4,7 @@ use crate::handler::{Handler, Traverse};
 use crate::{Program, ProgramRef};
 use deno_ast::swc::common::Spanned;
 use deno_ast::view as ast_view;
+use std::sync::Arc;
 
 #[derive(Debug)]
 pub struct NoWith;
@@ -12,8 +13,8 @@ const CODE: &str = "no-with";
 const MESSAGE: &str = "`with` statement is not allowed";
 
 impl LintRule for NoWith {
-  fn new() -> Box<Self> {
-    Box::new(NoWith)
+  fn new() -> Arc<Self> {
+    Arc::new(NoWith)
   }
 
   fn tags(&self) -> &'static [&'static str] {
