@@ -101,6 +101,7 @@ use crate::handler::{Handler, Traverse};
 use crate::{Program, ProgramRef};
 use deno_ast::swc::common::Spanned;
 use deno_ast::view as ast_view;
+use std::sync::Arc;
 
 #[derive(Debug)]
 pub struct ${pascalCasedLintName};
@@ -110,8 +111,8 @@ const MESSAGE: &str = "";
 const HINT: &str = "";
 
 impl LintRule for ${pascalCasedLintName} {
-  fn new() -> Box<Self> {
-    Box::new(${pascalCasedLintName})
+  fn new() -> Arc<Self> {
+    Arc::new(${pascalCasedLintName})
   }
 
   fn code(&self) -> &'static str {
